@@ -28,12 +28,11 @@ Helper functions for pytest.
 
 # stdlib
 import datetime
-import sys
 
 # this package
-from coincidence.fixtures import fixed_datetime, original_datadir, path_separator, tmp_pathplus
-from coincidence.params import count, testing_boolean_values, whitespace_perms
-from coincidence.regressions import (
+from coincidence.fixtures import fixed_datetime, original_datadir, path_separator, tmp_pathplus  # noqa: F401
+from coincidence.params import count, testing_boolean_values, whitespace_perms  # noqa: F401
+from coincidence.regressions import (  # noqa: F401
 		AdvancedDataRegressionFixture,
 		AdvancedFileRegressionFixture,
 		SupportsAsDict,
@@ -42,7 +41,7 @@ from coincidence.regressions import (
 		check_file_output,
 		check_file_regression
 		)
-from coincidence.selectors import (
+from coincidence.selectors import (  # noqa: F401
 		max_version,
 		min_version,
 		not_docker,
@@ -56,7 +55,7 @@ from coincidence.selectors import (
 		only_windows,
 		platform_boolean_factory
 		)
-from coincidence.utils import (
+from coincidence.utils import (  # noqa: F401
 		generate_falsy_values,
 		generate_truthy_values,
 		is_docker,
@@ -65,16 +64,18 @@ from coincidence.utils import (
 		with_fixed_datetime
 		)
 
+# import sys
+
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020-2021 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.5.0"
+__version__: str = "0.6.3"
 __email__: str = "dominic@davis-foster.co.uk"
 
-__all__ = ["pytest_report_header", "PEP_563"]
+__all__ = ("pytest_report_header", "PEP_563")
 
 
-def pytest_report_header(config, startdir):
+def pytest_report_header(config, startdir) -> str:  # noqa: MAN001
 	"""
 	Prints the start time of the pytest session.
 	"""
@@ -82,7 +83,14 @@ def pytest_report_header(config, startdir):
 	return f"Test session started at {datetime.datetime.now():%H:%M:%S}"
 
 
-PEP_563: bool = (sys.version_info[:2] >= (3, 11))
+PEP_563: bool = False  # (sys.version_info[:2] >= (3, 11))
 """
 :py:obj:`True` if the current Python version implements :pep:`563` -- Postponed Evaluation of Annotations.
+
+.. note::
+
+	This is currently set to :py:obj:`False` until the future of typing PEPs has been determined.
+	No released versions of Python currently have :pep:`563` enabled by default.
+
+.. versionchanged:: 0.6.0  Temporarily set to :py:obj:`False` regardless of version.
 """
